@@ -83,6 +83,11 @@ install_tinytex = function(
   not_ctan = repository != 'ctan'
   https = grepl('^https://', repository)
 
+  if (!grepl('TinyTeX', bundle)) message(
+    "The bundle name '", bundle, "' has been automatically corrected to '",
+    bundle <- gsub('tinytex', 'TinyTeX', bundle, ignore.case = TRUE), "'."
+  )
+
   owd = setwd(tempdir()); on.exit(setwd(owd), add = TRUE)
 
   if ((texinput <- Sys.getenv('TEXINPUT')) != '') message(
@@ -394,10 +399,6 @@ dir_copy = function(from, to) {
     unlink(from, recursive = TRUE) == 0
 }
 
-download_file = function(...) {
-  xfun::download_file(..., quiet = Sys.getenv('APPVEYOR') != '')
-}
-
 # LaTeX packages that I use
 install_yihui_pkgs = function() {
   pkgs = readLines('https://yihui.org/gh/tinytex/tools/pkgs-yihui.txt')
@@ -435,6 +436,8 @@ install_prebuilt = function(
       installer, if (version != '') paste0('-v', version), '.',
       c('zip', 'tar.gz', 'tgz')[os_index]
     )
+    # Full scheme is bundled as a self extracting archive on Windows
+    if (os_index == 1 && installer == 'TinyTeX-2') pkg = xfun::with_ext(pkg, "exe")
     if (file.exists(pkg) && is.na(cache)) {
       # invalidate cache (if unspecified) when the installer is more than one day old
       if (as.numeric(difftime(Sys.time(), file.mtime(pkg), units = 'days')) > 1)
@@ -449,8 +452,12 @@ install_prebuilt = function(
 
   # installation dir shouldn't be a file but a directory
   file.remove(exist_files(c(dir1, dir2)))
-  extract = if (grepl('[.]zip$', pkg)) unzip else untar
-  extract(pkg, exdir = path.expand(target))
+  if (grepl('[.]exe$', pkg)) {
+    system2(pkg, args = c('-y', paste0('-o', path.expand(target))))
+  } else {
+    extract = if (grepl('[.]zip$', pkg)) unzip else untar
+    extract(pkg, exdir = path.expand(target))
+  }
   # TinyTeX (or .TinyTeX) is extracted to the parent dir of `dir`; may need to rename
   if (dir != '') {
     if (basename(dir1) != b) file.rename(dir2, dir1)
@@ -487,7 +494,7 @@ download_installer = function(file, version) {
   url = if (version != '') sprintf(
     'https://github.com/rstudio/tinytex-releases/releases/download/v%s/%s', version, file
   ) else paste0(getOption('tinytex.install.url', 'https://yihui.org/tinytex/'), file)
-  download_file(url, file)
+  download_file(url, file, mode = 'wb')
 }
 
 #' Copy TinyTeX to another location and use it in another system
