@@ -36,7 +36,7 @@
 #' so that \code{latexmk()} knows where to find executables like
 #' \command{pdflatex}. For example, if you are using Windows and your TinyTeX is
 #' on an external drive \file{Z:/} under the folder \file{TinyTeX}, you may set
-#' \code{options(tinytex.tlmgr.path = "Z:/TinyTeX/bin/win32/tlmgr.bat")}.
+#' \code{options(tinytex.tlmgr.path = "Z:/TinyTeX/bin/windows/tlmgr.bat")}.
 #' Usually you should not need to set this option because TinyTeX can add itself
 #' to the \code{PATH} variable during installation or via
 #' \code{\link{use_tinytex}()}. In case both methods fail, you can use this
@@ -421,6 +421,7 @@ check_babel = function(text) {
   if (length(m <- grep_sub(r, 'hyphen-\\2', text)) == 0) return(FALSE)
   # (babel) the language `German (new orthography)' into the format
   m = gsub('\\s.*', '', m)
+  m[m == 'hyphen-pinyin'] = 'hyphen-chinese'
   tlmgr_install(tolower(m)) == 0
 }
 
@@ -593,7 +594,7 @@ regex_errors = function() {
       # missing .sty or commands
       ".* Loading '([^']+)' aborted!",
       ".*! LaTeX Error: File [`']([^']+)' not found.*",
-      ".* file ['`]?([^' ]+)'? not found.*",
+      ".* [fF]ile ['`]?([^' ]+)'? not found.*",
       '.*the language definition file ([^ ]+) .*',
       '.* \\(file ([^)]+)\\): cannot open .*',
       '.* open style file ([^ ]+).*',
